SystemOrganization addCategory: #'Zodiac-Tests'!

TestCase subclass: #ZdcAbstractSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcAbstractSocketStreamTests commentStamp: 'SvenVanCaekenberghe 5/17/2011 19:09' prior: 0!
ZdcAbstractSocketStreamTests holds units tests for socket streams.

This is an abstract class, subclasses should implement #socketStreamClass !

!ZdcAbstractSocketStreamTests class methodsFor: 'testing' stamp: 'SeanDeNigris 6/7/2012 10:10'!
isAbstract 

	^ self name = #ZdcAbstractSocketStreamTests.! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/17/2011 18:58'!
bytes: size
	| count data pattern |
	count := 0.
	pattern := (0 to: 255) asByteArray.
	data := ByteArray streamContents: [ :stream |
		[ count < size ] whileTrue: [
			stream nextPutAll: pattern.
			count := count + pattern size ] ].
	^ data copyFrom: 1 to: size     ! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:06'!
listenBacklogSize
	"Server socket backlog size (number of pending connection waiting to be accepted)"
	
	^ 32! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/17/2011 18:58'!
port 
	^ 1701! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/17/2011 19:06'!
runServer: block
	| serverSocket semaphore |
	serverSocket := self serverSocketOn: self port.
	self assert: serverSocket notNil.
	self assert: serverSocket localPort = self port.
	semaphore := Semaphore new.
	[ 
		semaphore signal.
		[ block cull: serverSocket cull: semaphore ]
			ensure: [ 
				serverSocket closeAndDestroy. 
				semaphore signal ] 
	] forkAt: Processor userBackgroundPriority.
	semaphore wait.
	^ semaphore 
! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/17/2011 19:05'!
serverSocketOn: port
	| socket |
	(socket := Socket newTCP)
		setOption: 'TCP_NODELAY' value: 1;
		setOption: 'SO_SNDBUF' value: self socketBufferSize;
		setOption: 'SO_RCVBUF' value: self socketBufferSize .
	socket listenOn: port backlogSize: self listenBacklogSize.
	socket isValid
		ifFalse: [ self error: 'Cannot create socket on port ', port printString ].
	^ socket! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:06'!
socketBufferSize
	"Size in bytes for Sockets and SocketStream IO buffers"

	^ 4096! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/17/2011 18:58'!
socketStreamClass
	^ self subclassResponsibility ! !

!ZdcAbstractSocketStreamTests methodsFor: 'private' stamp: 'SvenVanCaekenberghe 5/17/2011 19:06'!
socketStreamOn: socket
	| stream |
	(stream := SocketStream on: socket)
		binary;
		shouldSignal: true;
		autoFlush: false;
		bufferSize: self socketBufferSize;
		timeout: self socketStreamTimeout.
	^ stream! !

!ZdcAbstractSocketStreamTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:06'!
socketStreamTimeout
	"Timeout in seconds for SocketStream IO"
	
	^ 10! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 18:58'!
testAddOneEcho
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket | | clientSocket stream data |
		clientSocket := serverSocket waitForAcceptFor: 10.
		stream := self socketStreamClass on: clientSocket.
		data := stream next.
		stream nextPut: ((data + 1) bitAnd: 16rff).  
		stream close ].
	dataSent := 99.
	clientStream := self socketStreamClass openConnectionToHostNamed: 'localhost' port: self port.
	clientStream nextPut: dataSent; flush.
	dataRead := clientStream next.
	clientStream close.
	self assert: dataRead = (dataSent + 1).
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:07'!
testPlainClientRead
	| dataSent dataRead clientStream semaphore |
	dataSent := #[ 6 5 4 3 2 1 ].
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self socketStreamOn: clientSocket.
		serverStream nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self socketStreamClass openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := clientStream upToEnd.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:07'!
testPlainClientRead10k
	| dataSent dataRead clientStream semaphore |
	dataSent := self bytes: 10000.
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self socketStreamOn: clientSocket.
		serverStream nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self socketStreamClass openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := clientStream upToEnd.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:07'!
testPlainClientRead10kInPieces1
	| dataSent dataRead clientStream semaphore |
	dataSent := self bytes: 10000.
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self socketStreamOn: clientSocket.
		serverStream nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self socketStreamClass openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := ByteArray new: 10000 streamContents: [ :stream |
		10 timesRepeat: [ stream nextPutAll: (clientStream next: 1000) ] ].
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:07'!
testPlainClientRead10kInPieces2
	| dataSent dataRead clientStream semaphore |
	dataSent := self bytes: 10000.
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self socketStreamOn: clientSocket.
		serverStream nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self socketStreamClass openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := ByteArray new: 10000.
	0 to: 9 do: [ :index | 
		clientStream next: 1000 into: dataRead startingAt: (index * 1000) + 1 ].
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:07'!
testPlainClientSkip
	| dataSent dataRead clientStream semaphore |
	dataSent := #[ 6 5 4 3 2 1 ].
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self socketStreamOn: clientSocket.
		serverStream nextPut: 0; nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self socketStreamClass openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := clientStream skip: 1; upToEnd.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:07'!
testPlainClientSkip10k
	| dataSent dataRead clientStream semaphore |
	dataSent := #[ 6 5 4 3 2 1 ].
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self socketStreamOn: clientSocket.
		10000 timesRepeat: [ serverStream nextPut: 0 ].  
		serverStream nextPutAll: dataSent.
		serverStream close.
		mySemaphore signal ].
	clientStream := self socketStreamClass openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	dataRead := clientStream skip: 10000; upToEnd.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:07'!
testPlainClientWrite
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self socketStreamOn: clientSocket.
		dataRead := serverStream upToEnd.
		serverStream close.
		mySemaphore signal ].
	dataSent := #[ 1 2 3 4 5 6 ].
	clientStream := self socketStreamClass openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	clientStream nextPutAll: dataSent.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:07'!
testPlainClientWrite10k
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self socketStreamOn: clientSocket.
		dataRead := serverStream upToEnd.
		serverStream close.
		mySemaphore signal ].
	dataSent := self bytes: 10000.
	clientStream := self socketStreamClass openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	clientStream nextPutAll: dataSent.
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:07'!
testPlainClientWrite10kInPieces
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket :mySemaphore | | clientSocket serverStream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		serverStream := self socketStreamOn: clientSocket.
		dataRead := serverStream upToEnd.
		serverStream close.
		mySemaphore signal ].
	dataSent := self bytes: 10000.
	clientStream := self socketStreamClass openConnectionToHost: #[ 127 0 0 1 ] port: self port.
	0 to: 9 do: [ :index |
		clientStream next: 1000 putAll: dataSent startingAt: (1000 * index) + 1 ].
	clientStream close.
	semaphore wait.
	self assert: dataSent = dataRead.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 18:58'!
testReverseEcho
	| dataSent dataRead clientStream semaphore data |
	semaphore := self runServer: [ :serverSocket | | clientSocket stream |
		clientSocket := serverSocket waitForAcceptFor: 10.
		stream := self socketStreamClass on: clientSocket.
		data := stream upTo: 0.
		stream nextPutAll: data reverse; nextPut: 0.  
		stream close ].
	dataSent := #[ 1 2 3 4 5 6 ].
	clientStream := self socketStreamClass openConnectionToHostNamed: 'localhost' port: self port.
	clientStream nextPutAll: dataSent; nextPut: 0; flush.
	dataRead := clientStream upTo: 0.
	clientStream close.
	self assert: dataRead = dataSent reverse.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 18:58'!
testReverseEcho10kFixed
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket | | clientSocket stream data |
		clientSocket := serverSocket waitForAcceptFor: 10.
		stream := self socketStreamClass on: clientSocket.
		data := stream next: 10000.
		stream nextPutAll: data reverse.  
		stream close ].
	dataSent := self bytes: 10000.
	clientStream := self socketStreamClass openConnectionToHostNamed: 'localhost' port: self port.
	clientStream nextPutAll: dataSent; flush.
	dataRead := clientStream next: 10000.
	clientStream close.
	self assert: dataRead = dataSent reverse.
	semaphore wait! !

!ZdcAbstractSocketStreamTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 18:58'!
testReverseEcho10kSearch
	| dataSent dataRead clientStream semaphore |
	semaphore := self runServer: [ :serverSocket | | clientSocket stream data |
		clientSocket := serverSocket waitForAcceptFor: 10.
		stream := self socketStreamClass on: clientSocket.
		data := stream upTo: 0.
		stream nextPutAll: data reverse; nextPut: 0.  
		stream close ].
	dataSent := (self bytes: 10000) replace: [ :each | each max: 1 ].
	clientStream := self socketStreamClass openConnectionToHostNamed: 'localhost' port: self port.
	clientStream nextPutAll: dataSent; nextPut: 0; flush.
	dataRead := clientStream upTo: 0.
	clientStream close.
	self assert: dataRead = dataSent reverse.
	semaphore wait! !

ZdcAbstractSocketStreamTests subclass: #ZdcOptimizedSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcOptimizedSocketStreamTests commentStamp: 'SvenVanCaekenberghe 5/17/2011 19:09' prior: 0!
ZdcOptimizedSocketStreamTests tests ZdcOptimizedSocketStream!

!ZdcOptimizedSocketStreamTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/17/2011 18:59'!
socketStreamClass
	^ ZdcOptimizedSocketStream ! !

ZdcAbstractSocketStreamTests subclass: #ZdcReferenceSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcReferenceSocketStreamTests commentStamp: 'SvenVanCaekenberghe 5/20/2011 10:20' prior: 0!
ZdcReferenceSocketStreamTests test the reference SocketStream in the image!

!ZdcReferenceSocketStreamTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/20/2011 10:19'!
socketStreamClass
	^ SocketStream ! !

ZdcAbstractSocketStreamTests subclass: #ZdcSimpleSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcSimpleSocketStreamTests commentStamp: 'SvenVanCaekenberghe 5/17/2011 19:09' prior: 0!
ZdcSimpleSocketStreamTests tests ZdcSimpleSocketStream!

!ZdcSimpleSocketStreamTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/17/2011 18:59'!
socketStreamClass
	^ ZdcSimpleSocketStream ! !

ZdcAbstractSocketStreamTests subclass: #ZdcSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcSocketStreamTests commentStamp: 'SvenVanCaekenberghe 5/17/2011 19:09' prior: 0!
ZdcSocketStreamTests tests ZdcSocketStream!

!ZdcSocketStreamTests methodsFor: 'accessing' stamp: 'SvenVanCaekenberghe 5/17/2011 18:59'!
socketStreamClass
	^ ZdcSocketStream ! !

TestCase subclass: #ZdcIOBufferTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcIOBufferTests commentStamp: 'SvenVanCaekenberghe 5/17/2011 18:48' prior: 0!
ZdcIOBufferTests holds unit tests for ZdcIOBuffer.!

!ZdcIOBufferTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:28'!
testAdvanceReadPointer
	| ioBuffer offset |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	3 timesRepeat: [ ioBuffer nextPut: 0 ].
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].
	3 timesRepeat: [ ioBuffer next ].
	offset := ioBuffer contentsStart.
	self assert: ioBuffer availableForReading = 6.
	1 to: 6 do: [ :each | 
		self assert: (ioBuffer buffer at: offset + each - 1) = each ].
	ioBuffer advanceReadPointer: 6.
	self assert: ioBuffer availableForReading = 0.
	ioBuffer compact.
	self assert: ioBuffer isEmpty     
	! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:28'!
testAdvanceWritePointer
	| ioBuffer offset |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	self assert: ioBuffer isEmpty.
	offset := ioBuffer freeSpaceStart.
	1 to: 6 do: [ :each |
		ioBuffer buffer at: offset + each - 1 put: each ].
	ioBuffer advanceWritePointer: 6.
	self assert: ioBuffer isEmpty not.
	self assert: ioBuffer availableForReading = 6.
	self assert: ioBuffer contents = #[1 2 3 4 5 6]
	! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:28'!
testCompact
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].
	3 timesRepeat: [ ioBuffer next ].
	ioBuffer compact.
	self assert: ioBuffer availableForReading = 3.
	self assert: ioBuffer availableForWriting = 7.
	3 timesRepeat: [ ioBuffer next ].
	self assert: ioBuffer gapAtFront = 3.
	ioBuffer compact.
	self assert: ioBuffer isEmpty
	
		! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:28'!
testCompactAtBeginning
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	ioBuffer compact.
	self assert: ioBuffer isEmpty.
	self assert: ioBuffer availableForWriting = 10.
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].
	ioBuffer compact.
	self assert: ioBuffer availableForReading = 6.
	self assert: ioBuffer availableForWriting = 4.
	self assert: ioBuffer gapAtFront isZero! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:28'!
testCompactAtEnd
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	10 timesRepeat: [ ioBuffer nextPut: 1 ].
	self assert: ioBuffer gapAtFront isZero.
	10 timesRepeat: [ ioBuffer next ].
	self assert: ioBuffer isFull.
	self assert: ioBuffer gapAtFront = 10.
	ioBuffer compact.
	self assert: ioBuffer isEmpty
	
		! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:28'!
testCompactDoNothing
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	self assert: ioBuffer isEmpty.
	self assert: ioBuffer availableForReading = 0.
	self assert: ioBuffer availableForWriting = 10.
	ioBuffer compact.
	self assert: ioBuffer isEmpty.
	self assert: ioBuffer availableForReading = 0.
	self assert: ioBuffer availableForWriting = 10.	    
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].	
	self assert: ioBuffer isEmpty not.
	self assert: ioBuffer availableForReading = 6.
	self assert: ioBuffer availableForWriting = 4.
	ioBuffer compact.
	self assert: ioBuffer isEmpty not.
	self assert: ioBuffer availableForReading = 6.
	self assert: ioBuffer availableForWriting = 4.! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:29'!
testReading
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].
	1 to: 3 do: [ :each | self assert: ioBuffer next = each ].
	self assert: ioBuffer contents = #[4 5 6].
	4 to: 6 do: [ :each | self assert: ioBuffer next = each ].
	self assert: ioBuffer isEmpty.
	self should: [ ioBuffer next ] raise: Error! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:28'!
testString
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (String new: 10).
	($a to: $f) do: [ :each | ioBuffer nextPut: each ].
	self assert: ioBuffer contents = 'abcdef'.
	($a to: $f) do: [ :each | self assert: ioBuffer next = each ]
	
	! !

!ZdcIOBufferTests methodsFor: 'testing' stamp: 'SvenVanCaekenberghe 5/17/2011 19:28'!
testWriting
	| ioBuffer |
	ioBuffer := ZdcIOBuffer on: (ByteArray new: 10).
	self assert: ioBuffer isEmpty.
	self assert: ioBuffer size isZero.
	self assert: ioBuffer availableForWriting = 10.
	1 to: 6 do: [ :each | ioBuffer nextPut: each ].
	self assert: ioBuffer contents = #[1 2 3 4 5 6].
	self assert: ioBuffer size = 6.
	self assert: ioBuffer availableForWriting = 4.
	7 to: 10 do: [ :each | ioBuffer nextPut: each ].
	self assert: ioBuffer isFull.
	self should: [ ioBuffer nextPut: 1 ] raise: Error! !

TestCase subclass: #ZdcSecureSocketStreamTests
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Zodiac-Tests'!

!ZdcSecureSocketStreamTests commentStamp: 'SvenVanCaekenberghe 5/18/2011 11:52' prior: 0!
ZdcSecureSocketStreamTests tests ZdcSecureSocketStream !

!ZdcSecureSocketStreamTests methodsFor: 'tests' stamp: 'SvenVanCaekenberghe 5/18/2011 11:52'!
testPlain
	| query stream request response |
	query := 'Smalltalk'.
	stream := ZdcSecureSocketStream openConnectionToHostNamed: 'encrypted.google.com' port: 443.
	[
		request := String streamContents: [ :out |
			out << 'GET /search?q=' << query << ' HTTP/1.1' << String crlf.
			out << 'Host: encrypted.google.com' << String crlf.
			out << 'Connection: close' << String crlf.
			out << String crlf ].
		stream connect.
		stream nextPutAll: request asByteArray.
		stream flush.
		response := stream upToEnd asString.
	] ensure: [ stream close ].
	self assert: (response includesSubString: '200 OK').      
	self assert: (response includesSubString: 'Google').
	self assert: (response includesSubString: 'Smalltalk').      ! !
